/*
  Arduino 1813/TeensyDuino 1.53
  HID Bluetooth library - developed by Kristian Lauszus.
  For more information visit the blog: http://blog.tkjelectronics.dk/ .
  Also see for other library :
  https://github.com/felis/USB_Host_Shield_2.0
  and
  https://github.com/gdsports/xac-mouse2joy/blob/master/joystick_teensy_20181205.zip

****************
  Le développement de ce code a été modifié par Christian Fromentin MHK Rennes.

  Voir le fichier "Regarde-moi.txt" dans le dossier XAC-Joystick
  By default serial debugging is disabled. To turn it on simply change ENABLE_UHS_DEBUGGING to 1 in settings.h like so:

  {C++}
  #define ENABLE_UHS_DEBUGGING 1

  Le bouton reset est sur l'entrée 22
  Le controle de sensibilité est sur l'entrée Analogique A7.
  Le voyant Bleu sur la sortie 19
  Le voyant Rouge sur la sortie 20
  Le voyant Vert sur la sortie 23

  le reset soft permet de relancer le setup et de prendre en compte la position de l'ajustable
  qui servira a la definition de la senssibilité

*/


#include <hidboot.h>
#include <usbhub.h>
#include "MouseParser.h"


// Satisfy the IDE, which needs to see the include statment in the ino too.
#ifdef    dobogusinclude
#include  <spi4teensy3.h>
#endif
#include  <SPI.h>


USB         Usb;
USBHub      Hub(&Usb);
HIDBoot<USB_HID_PROTOCOL_MOUSE>    HidMouse(&Usb);

MouseRptParser  Prs;

const int       PWR_ON_led_pin      = 23; // Verte
const int       BTN_RST             = 22;
const int       ANALOG_IN           = A7;
const int       USB_MOVE_led_pin    = 20; //Rouge
const int       USB_CONNECT_led_pin = 19; // Bleu

uint8_t         usbstate;
boolean         buttonStateRst     = true;
int val;
unsigned long   lastTime           = 0;  // the last time the output pin was toggled
unsigned long   LedDelay           = 50;
boolean         firstboot          = true;
int             etatcnx            = 0;

#define SCB_AIRCR (*(volatile uint32_t *)0xE000ED0C) // Application Interrupt and Reset Control location


void setup()
{
  pinMode(PWR_ON_led_pin, OUTPUT);
  pinMode(BTN_RST, INPUT_PULLUP);
  pinMode(USB_MOVE_led_pin, OUTPUT);
  pinMode(USB_CONNECT_led_pin, OUTPUT);
  val = analogRead(ANALOG_IN);
  digitalWrite(USB_MOVE_led_pin, HIGH);
  digitalWrite(PWR_ON_led_pin, HIGH);
  digitalWrite(USB_CONNECT_led_pin, HIGH) ;
  delay(1000);
  digitalWrite(USB_MOVE_led_pin, LOW);
  digitalWrite(PWR_ON_led_pin, LOW);
  digitalWrite(USB_CONNECT_led_pin, LOW) ;
  delay(1000);
  digitalWrite(USB_MOVE_led_pin, HIGH);
  digitalWrite(PWR_ON_led_pin, HIGH);
  digitalWrite(USB_CONNECT_led_pin, HIGH) ;
  delay(1000);
  digitalWrite(USB_MOVE_led_pin, LOW);
  digitalWrite(PWR_ON_led_pin, LOW);
  digitalWrite(USB_CONNECT_led_pin, LOW) ;
  delay(1000);  
 // digitalWrite(PWR_ON_led_pin, HIGH);
  delay(100);
  digitalWrite(PWR_ON_led_pin, LOW);  // attente de l'initialisation du module Host_Usb

  if (Usb.Init() == -1) {
    // allume voyant Rouge; le système n'est pas opérationnel
    digitalWrite(USB_MOVE_led_pin, HIGH) ;
    Serial.println("Non Connecte");
  } else {
    // allume voyant Vert; le système est opérationnel
    digitalWrite(PWR_ON_led_pin, HIGH);
    Serial.println("Connecte");
  }

  if (!HidMouse.isReady()) {
    //   digitalWrite(USB_MOVE_led_pin, HIGH) ;
  } else {
    digitalWrite(USB_MOVE_led_pin, LOW) ;
  }

  HidMouse.SetReportParser(0, &Prs);
  // Ajustage de la valeur de sensisibilité au lancement.
  joy_factor1 = map(val, 0, 1023, -512, +512);
  Serial.println(joy_factor1);
}

void loop()
{
  // reboot logiciel
  buttonStateRst = digitalRead(BTN_RST);
  if (!buttonStateRst) {
    Serial.println("Button pressed!!!");
    _softRestart();
  }

  // lecture de la souris
  Usb.Task();

  // allume voyant bleu; la souris est connectée
  if (HidMouse.isReady()) {
    digitalWrite(USB_CONNECT_led_pin, HIGH) ;
  } else {
    digitalWrite(USB_CONNECT_led_pin, LOW) ;
  }

  // allume voyant rouge lors du déplacement de la souris
  if (move_Mouse ) {
    digitalWrite(USB_MOVE_led_pin, HIGH) ;
  }
  if ((millis() - lastTime) > LedDelay) {
    if (move_Mouse) {
      digitalWrite(USB_MOVE_led_pin, LOW) ;
      move_Mouse = false;
      lastTime = millis();
    }
  }
}

void _softRestart()
{
  Serial.end();  //clears the serial monitor  if used
  SCB_AIRCR = 0x05FA0004;  //write value for restart
}
